
This is a plan for next incompatible changes - they are primarily renames.

TODO: Decide `[script].conf` vs `[script].conf.bash` ? I think 2nd is more systematic.

*   TODO: Rename: `@/conf/python_conf.bash` -> `@/conf/python_venv.conf`
*   TODO: Rename: `@/conf/argrelay_rc_conf.bash` -> `@/conf/argrelay_rc.conf`
*   TODO: Rename: `@/exe/deploy_config_files_conf.bash` -> `@/exe/install_config_files.conf`

TODO:
*   Rename all enum items to underscore (e.g. `ServerAction.ProposeArgValues` -> `ServerAction.propse_args_values`).
*   Consider renaming URL, for example (`_` to `-`, shorten, rethink):
    *   propose_arg_values -> propose-options
    *   describe_line_args -> enum-options
    *   relay_line_args -> invoke-with-options

TODO:
*   Move all GUI config into DefaultConfigurator (including banner).
